"use strict";

require("core-js/modules/es6.object.define-property");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.mapper = void 0;

require("core-js/modules/es6.object.assign");

require("core-js/modules/es6.function.name");

require("core-js/modules/es6.regexp.search");

require("core-js/modules/es6.array.reduce");

var _react = _interopRequireDefault(require("react"));

var _memoizerific = _interopRequireDefault(require("memoizerific"));

var _components = require("@storybook/components");

var _persist = require("../settings/persist");

var _utils = require("../settings/utils");

var _nav = _interopRequireDefault(require("../components/nav/nav"));

var _context = require("../core/context");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var mapSymbol = function mapSymbol(el) {
  return el.reduce(function (a, b) {
    return "".concat(a, " ").concat((0, _utils.keyToSymbol)(b));
  }, '');
};

var createMenu = (0, _memoizerific.default)(1)(function (api, shortcutKeys, isFullscreen, showPanel, showNav, panelPosition) {
  return [{
    id: 'about',
    title: 'About your storybook',
    action: function action() {
      return api.navigate('/settings/about');
    },
    detail: api.versionUpdateAvailable() && _react.default.createElement(_components.Badge, null, "Update"),
    icon: ''
  }, {
    id: 'shortcuts',
    title: 'Keyboard Shortcuts',
    action: function action() {
      return api.navigate('/settings/shortcuts');
    },
    detail: mapSymbol(shortcutKeys.shortcutsPage),
    icon: ''
  }, {
    id: 'F',
    title: 'Go Fullscreen',
    action: function action() {
      return api.toggleFullscreen();
    },
    detail: mapSymbol(shortcutKeys.fullScreen),
    icon: isFullscreen ? 'check' : ''
  }, {
    id: 'S',
    title: 'Toggle Panel',
    action: function action() {
      return api.togglePanel();
    },
    detail: mapSymbol(shortcutKeys.togglePanel),
    icon: showPanel ? 'check' : ''
  }, {
    id: 'D',
    title: 'Toggle Panel Position',
    action: function action() {
      return api.togglePanelPosition();
    },
    detail: mapSymbol(shortcutKeys.panelPosition),
    icon: panelPosition === 'bottom' ? 'bottombar' : 'sidebaralt'
  }, {
    id: 'A',
    title: 'Toggle Navigation',
    action: function action() {
      return api.toggleNav();
    },
    detail: mapSymbol(shortcutKeys.navigation),
    icon: showNav ? 'check' : ''
  }, {
    id: '/',
    title: 'Search',
    action: function action() {},
    detail: mapSymbol(shortcutKeys.search),
    icon: 'search'
  }, {
    id: 'up',
    title: 'Previous component',
    action: function action() {
      return api.jumpToComponent(-1);
    },
    detail: mapSymbol(shortcutKeys.prevComponent),
    icon: ''
  }, {
    id: 'down',
    title: 'Next component',
    action: function action() {
      return api.jumpToComponent(1);
    },
    detail: mapSymbol(shortcutKeys.nextComponent),
    icon: ''
  }, {
    id: 'prev',
    title: 'Previous story',
    action: function action() {
      return api.jumpToStory(-1);
    },
    detail: mapSymbol(shortcutKeys.prevStory),
    icon: ''
  }, {
    id: 'next',
    title: 'Next story',
    action: function action() {
      return api.jumpToStory(1);
    },
    detail: mapSymbol(shortcutKeys.nextStory),
    icon: ''
  }];
});

var mapper = function mapper(state, api) {
  var _state$ui = state.ui,
      name = _state$ui.name,
      url = _state$ui.url,
      notifications = state.notifications,
      viewMode = state.viewMode,
      storyId = state.storyId,
      _state$layout = state.layout,
      isFullscreen = _state$layout.isFullscreen,
      showPanel = _state$layout.showPanel,
      showNav = _state$layout.showNav,
      panelPosition = _state$layout.panelPosition,
      storiesHash = state.storiesHash;

  var shortcutKeys = (0, _persist.get)('shortcutKeys') || _utils.serializableKeyboardShortcuts;

  return {
    title: name,
    url: url,
    notifications: notifications,
    stories: storiesHash,
    storyId: storyId,
    viewMode: viewMode,
    menu: createMenu(api, shortcutKeys, isFullscreen, showPanel, showNav, panelPosition),
    menuHighlighted: api.versionUpdateAvailable()
  };
};

exports.mapper = mapper;

var _default = function _default(props) {
  return _react.default.createElement(_context.Consumer, null, function (_ref) {
    var state = _ref.state,
        api = _ref.api;
    return _react.default.createElement(_nav.default, _extends({}, props, mapper(state, api)));
  });
};

exports.default = _default;