"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

require("core-js/modules/es6.promise");

require("core-js/modules/es6.object.define-property");

require("core-js/modules/es6.object.assign");

require("regenerator-runtime/runtime");

require("core-js/modules/web.dom.iterable");

require("core-js/modules/es6.array.iterator");

require("core-js/modules/es7.object.values");

require("core-js/modules/es6.array.find");

var _clientLogger = require("@storybook/client-logger");

var _fetch_latest_version = _interopRequireDefault(require("../libs/fetch_latest_version"));

var _package = require("../../package.json");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _default(_ref) {
  var store = _ref.store;

  // Should we make this an api? Does it make sense to call it anywhere except the init function below?
  function addVersion(_ref2) {
    var version = _ref2.version,
        tag = _ref2.tag,
        info = _ref2.info;

    var _store$getState = store.getState(),
        _store$getState$versi = _store$getState.versions,
        versions = _store$getState$versi === void 0 ? {} : _store$getState$versi;

    versions[version] = {
      version: version,
      tag: tag,
      info: info,
      current: _package.version === version
    };
    store.setState({
      versions: versions
    });
  }

  var state = {
    currentVersion: _package.version,
    versions: _defineProperty({}, _package.version, {
      version: _package.version,
      current: true
    })
  };
  var api = {
    getCurrentVersion: function getCurrentVersion() {
      var _store$getState2 = store.getState(),
          versions = _store$getState2.versions;

      return versions[_package.version];
    },
    getLatestVersion: function getLatestVersion() {
      var _store$getState3 = store.getState(),
          versions = _store$getState3.versions;

      return Object.values(versions).find(function (v) {
        return v.tag === 'latest';
      });
    },
    versionUpdateAvailable: function versionUpdateAvailable() {
      var latestVersion = api.getLatestVersion();
      return latestVersion && latestVersion.version !== store.getState().currentVersion;
    }
  }; // Grab versions from the server/local storage right away

  function init(_x) {
    return _init.apply(this, arguments);
  }

  function _init() {
    _init = _asyncToGenerator(
    /*#__PURE__*/
    regeneratorRuntime.mark(function _callee(_ref3) {
      var _ref3$api, versionUpdateAvailable, getLatestVersion, addNotification, _ref4, error, data;

      return regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _ref3$api = _ref3.api, versionUpdateAvailable = _ref3$api.versionUpdateAvailable, getLatestVersion = _ref3$api.getLatestVersion, addNotification = _ref3$api.addNotification;
              _context.next = 3;
              return (0, _fetch_latest_version.default)(_package.version);

            case 3:
              _ref4 = _context.sent;
              error = _ref4.error;
              data = _ref4.data;

              if (!error) {
                _context.next = 9;
                break;
              }

              _clientLogger.logger.warn("Failed to fetch latest version from server: ".concat(error));

              return _context.abrupt("return");

            case 9:
              addVersion(Object.assign({
                tag: 'latest'
              }, data.latest));

              if (versionUpdateAvailable()) {
                addNotification({
                  id: 'update',
                  level: 2,
                  link: '/settings/about',
                  icon: '🎉',
                  content: "There's a new version available: ".concat(getLatestVersion().version)
                });
              }

            case 11:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, this);
    }));
    return _init.apply(this, arguments);
  }

  return {
    init: init,
    state: state,
    api: api
  };
}