"use strict";

require("core-js/modules/es6.promise");

require("regenerator-runtime/runtime");

require("core-js/modules/es6.object.assign");

var _versions = _interopRequireDefault(require("./versions"));

var _fetch_latest_version = _interopRequireDefault(require("../libs/fetch_latest_version"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

jest.mock('../../package.json', function () {
  return {
    version: '3.0.0'
  };
});

function createMockStore() {
  var state = {};
  return {
    getState: jest.fn().mockImplementation(function () {
      return state;
    }),
    setState: jest.fn().mockImplementation(function (s) {
      state = Object.assign({}, state, s);
    })
  };
}

jest.mock('../libs/fetch_latest_version');
var standardResponse = {
  success: true,
  data: {
    latest: {
      version: '4.0.0'
    }
  }
};
jest.mock('@storybook/client-logger');
describe('versions API', function () {
  it('sets initial state with current version',
  /*#__PURE__*/
  _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee() {
    var _initVersions, state;

    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _initVersions = (0, _versions.default)({}), state = _initVersions.state;
            expect(state.currentVersion).toBe('3.0.0');
            expect(state.versions).toEqual({
              '3.0.0': expect.objectContaining({
                version: '3.0.0',
                current: true
              })
            });

          case 3:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  })));
  it('sets a update notification right away in the init function',
  /*#__PURE__*/
  _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee2() {
    var store, _initVersions2, init, api, initialState, addNotification;

    return regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            store = createMockStore();
            _initVersions2 = (0, _versions.default)({
              store: store
            }), init = _initVersions2.init, api = _initVersions2.api, initialState = _initVersions2.state;
            store.setState(initialState);

            _fetch_latest_version.default.mockResolvedValue(standardResponse);

            addNotification = jest.fn();
            _context2.next = 7;
            return init({
              api: Object.assign({
                addNotification: addNotification
              }, api)
            });

          case 7:
            expect(addNotification).toHaveBeenCalled();

          case 8:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2, this);
  })));
  it('sets versions in the init function',
  /*#__PURE__*/
  _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee3() {
    var store, _initVersions3, initialState, init, api;

    return regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            store = createMockStore();
            _initVersions3 = (0, _versions.default)({
              store: store
            }), initialState = _initVersions3.state, init = _initVersions3.init, api = _initVersions3.api;
            store.setState(initialState);

            _fetch_latest_version.default.mockResolvedValue(standardResponse);

            _context3.next = 6;
            return init({
              api: Object.assign({
                addNotification: jest.fn()
              }, api)
            });

          case 6:
            expect(store.setState).toHaveBeenCalledWith({
              versions: {
                '4.0.0': expect.objectContaining({
                  version: '4.0.0',
                  tag: 'latest'
                }),
                '3.0.0': expect.objectContaining({
                  version: '3.0.0',
                  current: true
                })
              }
            });

          case 7:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3, this);
  })));
  it('handles failures in ther versions function',
  /*#__PURE__*/
  _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee4() {
    var store, _initVersions4, init, api, initialState, addNotification;

    return regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            store = createMockStore();
            _initVersions4 = (0, _versions.default)({
              store: store
            }), init = _initVersions4.init, api = _initVersions4.api, initialState = _initVersions4.state;
            store.setState(initialState);

            _fetch_latest_version.default.mockResolvedValue({
              success: false,
              error: 'error'
            });

            addNotification = jest.fn();
            _context4.next = 7;
            return init({
              api: Object.assign({
                addNotification: addNotification
              }, api)
            });

          case 7:
            expect(addNotification).not.toHaveBeenCalled();
            expect(store.getState().versions).toEqual({
              '3.0.0': expect.objectContaining({
                version: '3.0.0',
                current: true
              })
            });

          case 9:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4, this);
  })));
  it('getCurrentVersion works',
  /*#__PURE__*/
  _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee5() {
    var store, _initVersions5, api, init, initialState;

    return regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            store = createMockStore();
            _initVersions5 = (0, _versions.default)({
              store: store
            }), api = _initVersions5.api, init = _initVersions5.init, initialState = _initVersions5.state;
            store.setState(initialState);

            _fetch_latest_version.default.mockResolvedValue(standardResponse);

            _context5.next = 6;
            return init({
              api: Object.assign({}, api, {
                addNotification: jest.fn()
              })
            });

          case 6:
            expect(api.getCurrentVersion()).toEqual({
              version: '3.0.0',
              current: true
            });

          case 7:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5, this);
  })));
  it('getLatestVersion works',
  /*#__PURE__*/
  _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee6() {
    var store, _initVersions6, api, init, initialState;

    return regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            store = createMockStore();
            _initVersions6 = (0, _versions.default)({
              store: store
            }), api = _initVersions6.api, init = _initVersions6.init, initialState = _initVersions6.state;
            store.setState(initialState);

            _fetch_latest_version.default.mockResolvedValue(standardResponse);

            _context6.next = 6;
            return init({
              api: Object.assign({}, api, {
                addNotification: jest.fn()
              })
            });

          case 6:
            expect(api.getLatestVersion()).toMatchObject({
              version: '4.0.0',
              tag: 'latest'
            });

          case 7:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6, this);
  })));
  it('versionUpdateAvailable works',
  /*#__PURE__*/
  _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee7() {
    var store, _initVersions7, api, init, initialState;

    return regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            store = createMockStore();
            _initVersions7 = (0, _versions.default)({
              store: store
            }), api = _initVersions7.api, init = _initVersions7.init, initialState = _initVersions7.state;
            store.setState(initialState);

            _fetch_latest_version.default.mockResolvedValue(standardResponse);

            _context7.next = 6;
            return init({
              api: Object.assign({}, api, {
                addNotification: jest.fn()
              })
            });

          case 6:
            expect(api.versionUpdateAvailable()).toEqual(true);

          case 7:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7, this);
  })));
});