"use strict";

require("core-js/modules/es6.object.define-property");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = handle;
exports.handleKeyboardShortcuts = handleKeyboardShortcuts;
exports.features = void 0;

require("core-js/modules/es6.regexp.to-string");

require("core-js/modules/es6.date.to-string");

require("core-js/modules/es7.symbol.async-iterator");

require("core-js/modules/es6.symbol");

require("core-js/modules/web.dom.iterable");

require("core-js/modules/es6.array.is-array");

require("core-js/modules/es6.string.iterator");

require("core-js/modules/es6.array.from");

var _coreEvents = _interopRequireDefault(require("@storybook/core-events"));

var _global = require("global");

var _utils = require("../settings/utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

var features = {
  FULLSCREEN: 'FULLSCREEN',
  PANEL_VISIBILITY: 'PANEL_VISIBILITY',
  NAV_VISIBILITY: 'NAV_VISIBILITY',
  TOOL_VISIBILITY: 'TOOL_VISIBILITY',
  SHORTCUTS_HELP: 'SHORTCUTS_HELP',
  ESCAPE: 'ESCAPE',
  NEXT_STORY: 'NEXT_STORY',
  PREV_STORY: 'PREV_STORY',
  NEXT_COMPONENT: 'NEXT_COMPONENT',
  PREV_COMPONENT: 'PREV_COMPONENT',
  FOCUS_SEARCH: 'FOCUS_SEARCH',
  FOCUS_NAV: 'FOCUS_NAV',
  FOCUS_IFRAME: 'FOCUS_IFRAME',
  FOCUS_PANEL: 'FOCUS_PANEL',
  PANEL_POSITION: 'PANEL_POSITION',
  SHORTCUTS: 'SHORTCUTS'
};
exports.features = features;

function focusInInput(e) {
  return /input|textarea/i.test(e.target.tagName) || e.target.getAttribute('contenteditable') !== null;
}

var pressed = {
  fullScreen: [],
  togglePanel: [],
  panelPosition: [],
  navigation: [],
  toolbar: [],
  search: [],
  focusNav: [],
  focusIframe: [],
  focusPanel: [],
  prevComponent: [],
  nextComponent: [],
  prevStory: [],
  nextStory: [],
  shortcutsPage: [],
  aboutPage: []
};

var addKeyToTempShortcutArr = function addKeyToTempShortcutArr(shortcutName) {
  var shortcutKeys = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var parsedEvent = arguments.length > 2 ? arguments[2] : undefined;

  if (shortcutKeys[shortcutName]) {
    var _pressed$shortcutName;

    var hotkeys = Array.from(shortcutKeys[shortcutName]);

    (_pressed$shortcutName = pressed[shortcutName]).push.apply(_pressed$shortcutName, _toConsumableArray(parsedEvent));

    pressed[shortcutName].splice(-hotkeys.length - 1, pressed[shortcutName].length - hotkeys.length);
    var stringified = pressed[shortcutName];
    return stringified.join('') === hotkeys.join('');
  }

  return undefined;
};

function handle(e) {
  var shortcutKeys = JSON.parse(_global.localStorage.getItem('shortcutKeys'));

  if (e.key === 'Escape') {
    return features.ESCAPE;
  }

  if (e.key === 'Enter' || e.key === 'Backspace' || e.key === 'Tab') {
    return false;
  }

  if (focusInInput(e)) {
    // if we're focused in an element that accepts input,
    // then we shouldn't perform a shortcut action
    return false;
  }

  var parsedEvent = (0, _utils.parseKey)(e);

  if ((e.ctrlKey || e.metaKey) && e.shiftKey && e.keyCode === 188) {
    return features.SHORTCUTS;
  }

  switch (!!parsedEvent) {
    case addKeyToTempShortcutArr('nextStory', shortcutKeys, parsedEvent):
      e.preventDefault();
      return features.NEXT_STORY;

    case addKeyToTempShortcutArr('prevStory', shortcutKeys, parsedEvent):
      e.preventDefault();
      return features.PREV_STORY;

    case addKeyToTempShortcutArr('prevComponent', shortcutKeys, parsedEvent):
      e.preventDefault();
      return features.PREV_COMPONENT;

    case addKeyToTempShortcutArr('nextComponent', shortcutKeys, parsedEvent):
      e.preventDefault();
      return features.NEXT_COMPONENT;

    case addKeyToTempShortcutArr('fullScreen', shortcutKeys, parsedEvent):
      e.preventDefault();
      return features.FULLSCREEN;

    case addKeyToTempShortcutArr('aboutPage', shortcutKeys, parsedEvent):
      e.preventDefault();
      return features.ABOUT;

    case addKeyToTempShortcutArr('togglePanel', shortcutKeys, parsedEvent):
      e.preventDefault();
      return features.PANEL_VISIBILITY;

    case addKeyToTempShortcutArr('panelPosition', shortcutKeys, parsedEvent):
      e.preventDefault();
      return features.PANEL_POSITION;

    case addKeyToTempShortcutArr('navigation', shortcutKeys, parsedEvent):
      e.preventDefault();
      return features.NAV_VISIBILITY;

    case addKeyToTempShortcutArr('toolbar', shortcutKeys, parsedEvent):
      e.preventDefault();
      return features.TOOL_VISIBILITY;

    case addKeyToTempShortcutArr('search', shortcutKeys, parsedEvent):
      e.preventDefault();
      return features.FOCUS_SEARCH;

    case addKeyToTempShortcutArr('focusNav', shortcutKeys, parsedEvent):
      e.preventDefault();
      return features.FOCUS_NAV;

    case addKeyToTempShortcutArr('focusIframe', shortcutKeys, parsedEvent):
      e.preventDefault();
      return features.FOCUS_IFRAME;

    case addKeyToTempShortcutArr('focusPanel', shortcutKeys, parsedEvent):
      e.preventDefault();
      return features.FOCUS_PANEL;

    default:
      return false;
  }
} // window.keydown handler to dispatch a key event to the preview channel


function handleKeyboardShortcuts(channel) {
  return function (event) {
    var parsedEvent = handle(event);

    if (parsedEvent) {
      channel.emit(_coreEvents.default.APPLY_SHORTCUT, {
        event: parsedEvent
      });
    }
  };
}