"use strict";

require("core-js/modules/es6.array.find");

require("core-js/modules/es6.object.assign");

require("core-js/modules/es6.regexp.search");

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _shortcuts = _interopRequireDefault(require("./shortcuts"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('ShortcutsPage', function () {
  it('renders correctly', function () {
    var comp = (0, _enzyme.shallow)(_react.default.createElement(_shortcuts.default, null));
    expect(comp).toExist();
  });
  it('handles a full mount', function () {
    var comp = (0, _enzyme.mount)(_react.default.createElement(_shortcuts.default, null));
    expect(comp).toExist();
    comp.unmount();
  });
  describe('duplicateFound', function () {
    it('returns true if there are duplicates', function () {
      var comp = (0, _enzyme.shallow)(_react.default.createElement(_shortcuts.default, null));
      comp.setState({
        activeInputField: 'fullScreen',
        inputArr: ['S']
      });
      var instance = comp.instance();
      expect(instance.duplicateFound()).toEqual(true);
    });
    it('returns false if there are no duplicates', function () {
      var comp = (0, _enzyme.shallow)(_react.default.createElement(_shortcuts.default, null));
      comp.setState({
        activeInputField: 'fullScreen',
        inputArr: ['R']
      });
      var instance = comp.instance();
      expect(instance.duplicateFound()).toEqual(false);
    });
  });
  describe('submitKeyHandler', function () {
    it('restores the default if the input array is empty', function () {
      var comp = (0, _enzyme.shallow)(_react.default.createElement(_shortcuts.default, null));
      comp.setState({
        activeInputField: 'togglePanel',
        inputArr: [],
        shortcutKeys: {
          togglePanel: {
            value: []
          }
        }
      });
      var instance = comp.instance();
      var spy = jest.spyOn(instance, 'restoreDefault');
      instance.submitKeyHandler();
      expect(spy).toHaveBeenCalledTimes(1);
    });
    it('returns undefined if inputArray has keys in it', function () {
      var comp = (0, _enzyme.shallow)(_react.default.createElement(_shortcuts.default, null));
      comp.setState({
        activeInputField: 'togglePanel',
        inputArr: ['R', '1'],
        shortcutKeys: {
          togglePanel: {
            value: ['R', '1']
          }
        }
      });
      var instance = comp.instance();
      expect(comp.state('shortcutKeys').togglePanel.value).toHaveLength(2);
      expect(instance.submitKeyHandler()).toBeUndefined();
    });
  });
  describe('handleBackspace', function () {
    it('cuts the last element from the inputArr', function () {
      var expected = ['A', 'B'];
      var comp = (0, _enzyme.shallow)(_react.default.createElement(_shortcuts.default, null));
      comp.setState({
        activeInputField: 'navigation',
        inputArr: ['A', 'B', 'C']
      });
      var instance = comp.instance();
      instance.handleBackspace();
      expect(comp.state('shortcutKeys').navigation.value).toEqual(expect.arrayContaining(expected));
      expect(comp.state('shortcutKeys').navigation.value).not.toContain('C');
      expect(comp.state('shortcutKeys').navigation.value).toHaveLength(2);
    });
  });
  describe('onKeyDown', function () {
    it('calls handleBackspace if Backspace key is pressed', function () {
      var comp = (0, _enzyme.shallow)(_react.default.createElement(_shortcuts.default, null));
      var instance = comp.instance();
      comp.setState({
        activeInputField: 'focusIframe',
        inputArr: ['A', 'B', 'C']
      });
      var spy = jest.spyOn(instance, 'handleBackspace');
      instance.onKeyDown({
        key: 'Backspace'
      });
      expect(spy).toHaveBeenCalledTimes(1);
    });
    it('calls submitKeyHandler if Tab key is pressed', function () {
      var comp = (0, _enzyme.shallow)(_react.default.createElement(_shortcuts.default, null));
      comp.setState({
        activeInputField: 'focusIframe',
        inputArr: ['A', 'B', 'C']
      });
      var instance = comp.instance();
      var spy = jest.spyOn(instance, 'submitKeyHandler');
      instance.onKeyDown({
        key: 'Tab'
      });
      expect(spy).toHaveBeenCalledTimes(1);
    });
    it('calls submitKeyHandler if Enter key is pressed', function () {
      var comp = (0, _enzyme.shallow)(_react.default.createElement(_shortcuts.default, null));
      comp.setState({
        activeInputField: 'focusIframe',
        inputArr: ['A', 'B', 'C']
      });
      var instance = comp.instance();
      var spy = jest.spyOn(instance, 'submitKeyHandler');
      instance.onKeyDown({
        key: 'Enter'
      });
      expect(spy).toHaveBeenCalledTimes(1);
    });
    it('sets state for regular key down events', function () {
      var comp = (0, _enzyme.shallow)(_react.default.createElement(_shortcuts.default, null));
      comp.setState({
        activeInputField: 'search',
        inputArr: []
      });
      var instance = comp.instance();
      instance.onKeyDown({
        key: 'M'
      });
      var shortcut = comp.state('shortcutKeys').search.value;
      expect(shortcut).toHaveLength(1);
      expect(shortcut).toContain('M');
      expect(comp.state('inputArr')).toContain('M');
    });
  });
  describe('onFocus', function () {
    it('calls setstate and clears the input on focus', function () {
      var comp = (0, _enzyme.shallow)(_react.default.createElement(_shortcuts.default, null));
      var instance = comp.instance();
      instance.onFocus('toolbar')();
      expect(comp.state('shortcutKeys').toolbar.value).toHaveLength(0);
      expect(comp.state('inputArr')).toHaveLength(0);
      expect(comp.state('activeInputField')).toBe('toolbar');
    });
  });
  describe('onBlur', function () {
    it('if the input is empty, restores the respective default', function () {
      var comp = (0, _enzyme.shallow)(_react.default.createElement(_shortcuts.default, null));
      var instance = comp.instance();
      comp.setState({
        activeInputField: 'focusNav',
        inputArr: [],
        shortcutKeys: Object.assign({}, comp.state.shortcutKeys, {
          focusNav: {
            value: []
          }
        })
      });
      instance.onBlur();
      expect(comp.state('shortcutKeys').focusNav.value).toHaveLength(1);
      expect(comp.state('shortcutKeys').focusNav.value).toContain('1');
    });
    it('if a duplicate is found, it sets error to true', function () {
      var comp = (0, _enzyme.shallow)(_react.default.createElement(_shortcuts.default, null));
      var instance = comp.instance();
      comp.setState({
        activeInputField: 'fullScreen',
        inputArr: ['S']
      });
      instance.onBlur();
      expect(comp.state('shortcutKeys').fullScreen.error).toBe(true);
    });
    it('it saves the shortcut if it is valid', function () {
      var comp = (0, _enzyme.shallow)(_react.default.createElement(_shortcuts.default, null));
      var instance = comp.instance();
      comp.setState({
        activeInputField: 'focusNav',
        inputArr: ['V', 'P']
      });
      instance.onBlur();
      var spy = jest.spyOn(instance, 'saveShortcut');
      instance.onBlur();
      expect(spy).toHaveBeenCalledTimes(1);
    });
  });
  describe('saveShortcut', function () {
    it('if the input is empty, restores the respective default', function () {
      var comp = (0, _enzyme.shallow)(_react.default.createElement(_shortcuts.default, null));
      var instance = comp.instance();
      comp.setState({
        activeInputField: 'focusNav',
        inputArr: [],
        shortcutKeys: {
          focusNav: {
            value: []
          }
        }
      });
      instance.onBlur();
      expect(comp.state('shortcutKeys').focusNav.value).toEqual(['1']);
    });
  });
  describe('restoreDefaults', function () {
    it('if the input is empty, restores the respective default', function () {
      var comp = (0, _enzyme.shallow)(_react.default.createElement(_shortcuts.default, null));
      comp.setState({
        activeInputField: 'focusNav',
        inputArr: ['G', 'H'],
        shortcutKeys: {
          focusNav: {
            value: ['G', 'H'],
            error: false
          }
        }
      });
      comp.find('#restoreDefaultsHotkeys').simulate('click');
      var newState = comp.state('shortcutKeys').focusNav.value;
      expect(newState).toEqual(['1']);
    });
  });
});